.. _compress_kwargs:

compress() Keyword Arguments Listing
====================================

See also the documentation for :py:func:`stitch_core.compress`.

.. include:: generated_kwargs_table.rst
